@@ -1,15 +1,15 @@
 """Main file for clifold."""
 import argparse
 
-from clifold.clifold_git import git_init
-from clifold.clifold_init import py_init
-from clifold.clifold_pkg import pip
-from clifold.clifold_project import create
+from clifold.commands.clifold_git import git_init
+from clifold.commands.clifold_init import py_init
+from clifold.commands.clifold_pkg import pip
+from clifold.commands.clifold_project import create
 
 
 def __version__():
     """return package version"""
-    return "0.1.1"
+    return "0.2.0"
 
 
 def cli():
@@ -51,9 +51,11 @@ def cli():
     init = args.init
 
     ppath = create(pname)
-    git_init(git, ppath)
-    pip(pkg, ppath)
-    py_init(init, ppath, pname)
+    git_return = git_init(git, ppath)
+    pkg_return = pip(pkg, ppath, pname)
+    init_return = py_init(init, ppath, pname)
+
+    return ppath, git_return, pkg_return, init_return
 
 
 if __name__ == "__main__":
